# eric7.VCS.RepositoryInfoDialog

Module implemting a dialog to show repository information.

### Global Attributes

None

### Classes

VcsRepositoryInfoDialog | Class implemting a dialog to show repository information.

### Functions

None

## VcsRepositoryInfoDialog

Class implemting a dialog to show repository information.

### Derived from

QDialog, Ui_VcsRepositoryInfoDialog

### Class Attributes

None

### Class Methods

None

### Methods

VcsRepositoryInfoDialog | Constructor

### Static Methods

None

#### VcsRepositoryInfoDialog (Constructor)

VcsRepositoryInfoDialog(parent, info)

Constructor

parent (QWidget)
  reference to the parent widget
info (str)
  info data to show

Up